@@ -110,60 +110,6 @@ class CensorKeyword(object):
         self._keyword_to_group_id()
         self._init_search()
 
-    def which_group_id(self, text):#请用新接口 keyword_dict
-        text = text.lower()
-        total_group = len(self.group_name_list)
-        group = total_group
-        # 返回精确的命中关键词
-        match_keys = set()
-
-        single_search = self.single_search.count(text)
-        all_keys = single_search.keys()
-        if single_search:
-            for key in single_search.keys():
-                cat_id = self.single_keyword_to_cat_id[key]
-                if cat_id < group:
-                    group = cat_id
-                match_keys.add(key)
-        group_search = self.group_search.count(text)
-        all_keys.extend(group_search.keys())
-        all_keys = set(all_keys)
-
-        group_count = defaultdict(int)
-        for k in group_search.keys():
-            group_id_list = self.group_keyword_to_group_id.get(k, ())
-            for i in group_id_list:
-                group_count[i]+=1
-
-        for k, v in group_count.iteritems():
-            if self.group_keyword_length[k] <= v:
-                may_hav_keyword = self.may_hav_keyword[k]
-                if may_hav_keyword:
-                    min_num, may_set = may_hav_keyword
-                    matched = may_set&all_keys
-                    if len(matched)< min_num:
-                        continue
-                    for matched_i in matched:
-                        match_keys.add(matched_i)
-                
-                for w in self.group_keyword[k]:
-                    match_keys.add(w)
-                
-                #返回最小的那个 事前比事后优先级高
-                cat_id = self.group_id_to_cat_id[k]
-                if cat_id < group:
-                    group = cat_id
-
-
-        if group < total_group:
-            return group, list(match_keys)
-
-    def which_group_name(self, text):#请用新接口 keyword_dict
-        pos = self.which_group_id(text)
-        if pos is not None:
-            pos , keywords = pos
-            keywords = " ".join(keywords)
-            return self.group_name_list[pos], keywords
 
     def keyword_dict(self, text):
         text = text.lower()
